@@ -58,8 +58,6 @@ class TextListing:
         """
 
         # handle case where first line does not have a line number
-        line_no = 0
-        # this initial value popped after three line numbers are appended
         ln_num_buffer = [0]
 
         for line in raw_listing:
@@ -76,7 +74,7 @@ class TextListing:
 
             except ValueError:
                 return (
-                    f"Entry error after line {line_no} - "
+                    f"Entry error after line {ln_num_buffer.pop(0)} - "
                     "each line should start with a line number.  Exiting."
                 )
         return None
@@ -124,8 +122,15 @@ class TextListing:
             # check for loose braces in each substring, return error indication
             for sub_str in str_split:
                 loose_brace = re.search(r"\}|{", sub_str)
-                if loose_brace is not None:
-                    return str(self.split_line_num(line)[0])
+                if loose_brace:
+                    bad_line = self.split_line_num(line)[0]
+                    return (
+                        f"Loose brace/bracket error in line: {bad_line}\n"
+                        "Special characters should be enclosed in "
+                        "braces/brackets.\n"
+                        "Please check for unmatched single brace/bracket "
+                        "in above line."
+                    )
 
         return None
 
@@ -160,7 +165,6 @@ class TextListing:
             num = 0
 
             for item in code_split:
-
                 if item.upper() in AHOY_TO_PETCAT:
                     new_codes.append(AHOY_TO_PETCAT[item.upper()])
 
@@ -171,10 +175,10 @@ class TextListing:
                     )
                     # Get the string inside the brackets and strip quotes
                     char_code = re.search(
-                        r"\".+?\"", item  # type: ignore
-                    ).group()[
+                        r"\".+?\"", item
+                    ).group()[  # type: ignore
                         1:-1
-                    ]  # type: ignore
+                    ]
                     if char_code.upper() in AHOY_TO_PETCAT:
                         new_codes.append(AHOY_TO_PETCAT[char_code.upper()])
 
@@ -192,9 +196,9 @@ class TextListing:
                             num += 1
                             char_count -= 1
 
-                # else:
-                # new_codes.append(item)
-                # num += 1
+                else:
+                    new_codes.append(item)
+                num += 1
 
             # add blank item to list of special characters prior to blending
             if new_codes:
@@ -330,6 +334,7 @@ class Checksums:
             next_value = next_value << 1
 
         xor_value = next_value
+
         # get high nibble of xor_value
         high_nib = (xor_value & 0xF0) >> 4
         high_char_val = high_nib + 65  # 0x41
